@@ -1,13 +1,13 @@
-library("future")
+source("incl/start.R")
 library("listenv")
-
-ovars <- ls()
-oopts <- options(warn=1L, mc.cores=2L, future.globals.resolve=TRUE, future.debug=TRUE)
-##setTimeLimit(cpu=180, elapsed=180, transient=TRUE)
+oopts <- c(oopts, options(
+  future.globals.resolve=TRUE,
+  future.globals.onMissing="error"
+))
 
 message("*** Tricky use cases related to globals ...")
 
-strategies <- future:::supportedStrategies()
+strategies <- supportedStrategies()
 strategies <- setdiff(strategies, "multiprocess")
 
 for (cores in 1:min(3L, availableCores())) {
@@ -21,7 +21,7 @@ for (cores in 1:min(3L, availableCores())) {
   methods <- c("conservative", "ordered")
 
   for (method in methods) {
-    options("future.globalsMethod"=method)
+    options(future.globals.method=method)
     message(sprintf("Method for identifying globals: '%s' ...", method))
 
     for (strategy in strategies) {
@@ -93,9 +93,4 @@ for (cores in 1:min(3L, availableCores())) {
 
 message("*** Tricky use cases related to globals ... DONE")
 
-
-## Cleanup
-##setTimeLimit()
-plan(eager)
-options(oopts)
-rm(list=setdiff(ls(), ovars))
+source("incl/end.R")
